import os
import time
import app.servicecontrol

START_TIMEOUT = 30

class ServiceController(app.servicecontrol.ServiceController):
    def __init__(self, service, logger):
        super(ServiceController, self).__init__(service, logger)
        self.__lastStartupTime = 0

    def getPidFile(self):
        pidFile = "/var/run/elasticsearch/elasticsearch.pid"
        if os.path.isfile(pidFile):
            return pidFile

    def __runInit(self, command):
        config = app.util.getRuntimeConfiguration()
        logFile = os.path.join(config["ELASTICSEARCH_LOG_DIR"], "service.log")
        initScript = '/etc/init.d/elasticsearch'
        return os.system("JAVA_HOME=%s %s %s < /dev/null >> %s 2>&1 &" % (config["JAVA_HOME"], initScript, command, logFile)) == 0

    def isStarting(self):
        # Elasticsearch does not immediately publish its PID file - but that does not mean
        # it is in trouble. So we need to give it some extra time before making any status
        # decisions.
        return not self.getPid() and (time.time() - self.__lastStartupTime) < START_TIMEOUT

    def isBootstrapped(self):
        cfg = app.util.getRuntimeConfiguration()
        return os.path.isdir(cfg['ELASTICSEARCH_DATA_DIR'])

    def startDaemonAsync(self):
        if self.__runInit("start"):
            self.__lastStartupTime = time.time()
            return True
        else:
            return False

    def stopDaemonAsync(self):
        return self.__runInit("stop")
